@@ -15,7 +15,7 @@ JsonTypes = Union[str,dict,list,int,float,None]
 
 class Validator(object):
 
-    def __init__(self, schema:dict, _lazy_error_reporting=False):
+    def __init__(self, schema:dict, lazy_error_reporting=False):
         self.generic_validators = {
             "type": self._validate_type,
             "anyOf": self._validate_anyof,
@@ -50,7 +50,7 @@ class Validator(object):
         self._root_schema = schema
         self._file_loader = None
         self._temp_ignore_errors = False
-        self._lazy_error_reporting = _lazy_error_reporting
+        self._lazy_error_reporting = lazy_error_reporting
         self._errors = []
 
     @staticmethod
@@ -91,9 +91,9 @@ class Validator(object):
             return self.validate(data, schema)
 
     def _report_validation_error(self, message:str, data=None, schema=None) -> bool:
-        if hasattr(data, "line"):
+        if hasattr(data, "line") and data.line is not None:
             message = "Input line {}: {}".format(data.line, message)
-        if hasattr(schema, "line"):
+        if hasattr(schema, "line") and schema.line is not None:
             message = "{} (schema line {})".format(message, schema.line)
         if not self._lazy_error_reporting:
             raise JsonSchemaValidationError(message)
@@ -143,10 +143,11 @@ class Validator(object):
             raise InvalidSchemaError("Properties schema must be an object")
         if not isinstance(data, dict):
             return self._report_validation_error("Cannot validate properties on a non-object", data, schema)
+        retval = True
         for k, v in data.items():
             if k in schema:
-                self.validate(v, schema[k])
-        return True
+                retval = self.validate(v, schema[k]) and retval
+        return retval
 
     def _validate_pattern_properties(self, data:Dict[str,JsonTypes], schema:Dict[str,dict]) -> bool:
         if not isinstance(data, dict):
@@ -259,9 +260,10 @@ class Validator(object):
     def _validate_allof(self, data:JsonTypes, schemas:List[dict]) -> bool:
         if not isinstance(schemas, list):
             raise InvalidSchemaError("AnyOf schema was not a list")
+        retval = True
         for schema in schemas:
-            self.validate(data, schema)
-        return True
+            retval = self.validate(data, schema) and retval
+        return retval
 
     def _validate_not(self, data:JsonTypes, schema:dict) -> bool:
         try:
@@ -387,7 +389,7 @@ class Validator(object):
                 if additionalItems:
                     retval = self._validate_prefixitems(data[:schema_len], schema)
                     for item in data[schema_len:]:
-                        retval = (additionalItems is True) or self.validate(item, additionalItems)
+                        retval = ((additionalItems is True) or self.validate(item, additionalItems)) and retval
                     return retval
                 else:
                     return self._report_validation_error("There are too many items when additional items is false", data, schema)
@@ -436,7 +438,7 @@ class Validator(object):
         retval = True
         additionalItems = schema['additionalItems'] if 'additionalItems' in schema else True
         if 'items' in schema:
-            retvat = self._validate_items(data, schema['items'], additionalItems)
+            retval = self._validate_items(data, schema['items'], additionalItems)
         for k, validator_func in self.array_validators.items():
             if k in schema:
                 retval = validator_func(data, schema[k]) and retval
@@ -460,10 +462,10 @@ class Validator(object):
         retval = True
         if 'maximum' in schema:
             exclusive = schema['exclusiveMaximum'] if 'exclusiveMaximum' in schema else False
-            retval = self._validate_maximum(data, schema['maximum'], exclusive=exclusive)
+            retval = self._validate_maximum(data, schema['maximum'], exclusive=exclusive) and retval
         if 'minimum' in schema:
             exclusive = schema['exclusiveMinimum'] if 'exclusiveMinimum' in schema else False
-            retval = self._validate_minimum(data, schema['minimum'], exclusive=exclusive)
+            retval = self._validate_minimum(data, schema['minimum'], exclusive=exclusive) and retval
         for k, validator_func in self.value_validators.items():
             if k in schema:
                 retval = validator_func(data, schema[k]) and retval
